# pfse_starterkit
A Python package that installs all required packages for the StructuralPython Python for Structural Engineers (pfse) course.

This installs the following packages:

* streamlit
* numpy
* pandas
* openpyxl
* lxml
* shapely
* matplotlib
* plotly
* sectionproperties
* concreteproperties
* PyNiteFEA
* pycba
* scipy
* handcalcs
* forallpeople
* pytest
* ipytest
* rich
* tqdm
* papermodels
* xlwings
* black
* jupyterlab
* IPython
* ipywidgets
* ipykernel
* jupyterlab-mathjax3 (as an option)
* nbconvert
* flit
* python-docx
* constable
* black
